Class GraphqlErrorException

All Implemented Interfaces:
GraphQLError, Serializable
Direct Known Subclasses:
CoercingParseLiteralException, CoercingParseValueException, CoercingSerializeException

@PublicApi @NullMarked public class GraphqlErrorException extends GraphQLException implements GraphQLError
A base class for graphql runtime exceptions that also implement GraphQLError and can be used in a general sense direct or have specialisations made of it.

This is aimed amongst other reasons at Kotlin consumers due to ... as well as being a way to share common code.

See Also: