Package graphql
Class TypeMismatchError
java.lang.Object
graphql.TypeMismatchError
- All Implemented Interfaces:
GraphQLError,Serializable
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface graphql.GraphQLError
GraphQLError.Builder<B extends GraphQLError.Builder<B>> -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionboolean@Nullable List<SourceLocation> getPath()The graphql spec says that the (optional) path field of any error must be a list of path entries starting at the root of the response and ending with the field associated with the error ...inthashCode()toString()Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface graphql.GraphQLError
getExtensions, toSpecification
-
Constructor Details
-
TypeMismatchError
-
-
Method Details
-
getMessage
- Specified by:
getMessagein interfaceGraphQLError- Returns:
- a description of the error intended for the developer as a guide to understand and correct the error Non-nullable from the spec: Every error must contain an entry with the key "message" with a string description of the error intended for the developer as a guide to understand and correct the error.
-
getLocations
- Specified by:
getLocationsin interfaceGraphQLError- Returns:
- the location(s) within the GraphQL document at which the error occurred. Each
SourceLocationdescribes the beginning of an associated syntax element
-
getErrorType
- Specified by:
getErrorTypein interfaceGraphQLError- Returns:
- an object classifying this error
-
getPath
Description copied from interface:GraphQLErrorThe graphql spec says that the (optional) path field of any error must be a list of path entries starting at the root of the response and ending with the field associated with the error ...- Specified by:
getPathin interfaceGraphQLError- Returns:
- the path in list format
-
toString
-
equals
-
hashCode
public int hashCode()
-