Class ExecutionStrategyParameters

java.lang.Object
graphql.execution.ExecutionStrategyParameters

@PublicApi @NullMarked public class ExecutionStrategyParameters extends Object
The parameters that are passed to execution strategies
  • Method Details

    • getExecutionStepInfo

      public ExecutionStepInfo getExecutionStepInfo()
    • getSource

      public @Nullable Object getSource()
    • getFields

      public MergedSelectionSet getFields()
    • getNonNullFieldValidator

      public NonNullableFieldValidator getNonNullFieldValidator()
    • getPath

      public ResultPath getPath()
    • getLocalContext

      public @Nullable Object getLocalContext()
    • getParent

      public @Nullable ExecutionStrategyParameters getParent()
    • getDeferredCallContext

      public @Nullable AlternativeCallContext getDeferredCallContext()
      Returns the deferred call context if we're in the scope of a deferred call. A new DeferredCallContext is created for each @defer block, and is passed down to all fields within the deferred call.
          query {
             ... @defer {
                 field1 {        # new DeferredCallContext created here
                     field1a     # DeferredCallContext passed down to this field
                 }
             }
      
             ... @defer {
                 field2          # new DeferredCallContext created here
             }
          }
      
      Returns:
      the deferred call context or null if we're not in the scope of a deferred call
    • isInDeferredContext

      public boolean isInDeferredContext()
      Returns true if we're in the scope of a deferred call.
      Returns:
      true if we're in the scope of a deferred call
    • getField

      public @Nullable MergedField getField()
      This returns the current field in its query representations.
      Returns:
      the current merged fields
    • transform

    • toString

      public String toString()
      Overrides:
      toString in class Object
    • newParameters

      public static ExecutionStrategyParameters.Builder newParameters()
    • newParameters

      public static ExecutionStrategyParameters.Builder newParameters(ExecutionStrategyParameters oldParameters)