Package graphql.execution.incremental
Class IncrementalExecutionContextKeys
java.lang.Object
graphql.execution.incremental.IncrementalExecutionContextKeys
GraphQLContext keys for controlling incremental execution behavior.
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final StringEnables eager start of @defer processing so defered work runs before the initial result is computed. -
Method Summary
-
Field Details
-
ENABLE_EAGER_DEFER_START
Enables eager start of @defer processing so defered work runs before the initial result is computed. Defaults to false.Expects a boolean value.
- See Also:
-