public class NoOpPreparsedDocumentProvider extends java.lang.Object implements PreparsedDocumentProvider
| Modifier and Type | Field and Description |
|---|---|
static NoOpPreparsedDocumentProvider |
INSTANCE |
| Constructor and Description |
|---|
NoOpPreparsedDocumentProvider() |
| Modifier and Type | Method and Description |
|---|---|
PreparsedDocumentEntry |
getDocument(ExecutionInput executionInput,
java.util.function.Function<ExecutionInput,PreparsedDocumentEntry> computeFunction)
This is called to get a "cached" pre-parsed query and if its not present, then the computeFunction
can be called to parse and validate the query
|
public static final NoOpPreparsedDocumentProvider INSTANCE
public PreparsedDocumentEntry getDocument(ExecutionInput executionInput, java.util.function.Function<ExecutionInput,PreparsedDocumentEntry> computeFunction)
PreparsedDocumentProvidergetDocument in interface PreparsedDocumentProviderexecutionInput - The ExecutionInput containing the querycomputeFunction - If the query has not be pre-parsed, this function can be called to parse itPreparsedDocumentEntry