public static enum I18n.BundleType extends java.lang.Enum<I18n.BundleType>
| Enum Constant and Description |
|---|
Execution |
General |
Validation |
| Modifier and Type | Method and Description |
|---|---|
static I18n.BundleType |
valueOf(java.lang.String name)
Returns the enum constant of this type with the specified name.
|
static I18n.BundleType[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final I18n.BundleType Validation
public static final I18n.BundleType Execution
public static final I18n.BundleType General
public static I18n.BundleType[] values()
for (I18n.BundleType c : I18n.BundleType.values()) System.out.println(c);
public static I18n.BundleType valueOf(java.lang.String name)
name - the name of the enum constant to be returned.java.lang.IllegalArgumentException - if this enum type has no constant with the specified namejava.lang.NullPointerException - if the argument is null