Package graphql.incremental
Class IncrementalPayload
java.lang.Object
graphql.incremental.IncrementalPayload
- Direct Known Subclasses:
DeferPayload,StreamPayload
Represents a payload that can be resolved after the initial response.
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionprotected static class -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedIncrementalPayload(List<Object> path, String label, List<GraphQLError> errors, Map<Object, Object> extensions) -
Method Summary
Modifier and TypeMethodDescriptionbooleanprotected ObjecterrorsToSpec(List<GraphQLError> errors) @Nullable List<GraphQLError> @Nullable StringgetLabel()getPath()inthashCode()
-
Constructor Details
-
IncrementalPayload
-
-
Method Details
-
getPath
- Returns:
- list of field names and indices from root to the location of the corresponding `@defer` or `@stream` directive.
-
getLabel
- Returns:
- value derived from the corresponding `@defer` or `@stream` directive.
-
getErrors
- Returns:
- a list of field errors encountered during execution.
-
getExtensions
- Returns:
- a map of extensions or null if there are none
-
toSpecification
-
errorsToSpec
-
hashCode
public int hashCode() -
equals
-