Class IntrospectionDisabledError

java.lang.Object
graphql.introspection.IntrospectionDisabledError
All Implemented Interfaces:
GraphQLError, Serializable

public class IntrospectionDisabledError extends Object implements GraphQLError
See Also:
  • Constructor Details

    • IntrospectionDisabledError

      public IntrospectionDisabledError(SourceLocation sourceLocation)
  • Method Details

    • getMessage

      public String getMessage()
      Specified by:
      getMessage in interface GraphQLError
      Returns:
      a description of the error intended for the developer as a guide to understand and correct the error Non-nullable from the spec: Every error must contain an entry with the key "message" with a string description of the error intended for the developer as a guide to understand and correct the error.
    • getLocations

      public List<SourceLocation> getLocations()
      Specified by:
      getLocations in interface GraphQLError
      Returns:
      the location(s) within the GraphQL document at which the error occurred. Each SourceLocation describes the beginning of an associated syntax element
    • getErrorType

      public ErrorClassification getErrorType()
      Specified by:
      getErrorType in interface GraphQLError
      Returns:
      an object classifying this error