Class AstPrinter
java.lang.Object
graphql.language.AstPrinter
- Direct Known Subclasses:
PrettyAstPrinter
This can take graphql language AST and print it out as a string
-
Method Summary
Modifier and TypeMethodDescriptionstatic StringThis will pretty print the AST node in graphql language formatstatic voidThis will pretty print the AST node in graphql language formatstatic StringprintAstCompact(Node node) This will print the Ast node in graphql language format in a compact manner, with no new lines and descriptions stripped out of the text.static voidprintAstTo(Node<?> node, Appendable appendable) This will pretty print the AST node in graphql language format to the given Appendable
-
Method Details
-
printAst
-
printAstTo
This will pretty print the AST node in graphql language format to the given Appendable- Parameters:
node- the AST node to printappendable- the Appendable to write the output to
-
printAst
-
printAstCompact
-