Class GraphqlBaseVisitor<T>

java.lang.Object
org.antlr.v4.runtime.tree.AbstractParseTreeVisitor<T>
graphql.parser.antlr.GraphqlBaseVisitor<T>
Type Parameters:
T - The return type of the visit operation. Use Void for operations with no return type.
All Implemented Interfaces:
GraphqlVisitor<T>, org.antlr.v4.runtime.tree.ParseTreeVisitor<T>

public class GraphqlBaseVisitor<T> extends org.antlr.v4.runtime.tree.AbstractParseTreeVisitor<T> implements GraphqlVisitor<T>
This class provides an empty implementation of GraphqlVisitor, which can be extended to create a visitor which only needs to handle a subset of the available methods.