Interface Connection<T>

All Known Implementing Classes:
DefaultConnection

@PublicApi @NullMarked public interface Connection<T>
This represents a connection in Relay, which is a list of edges as well as a pageInfo that describes the pagination of that list.

See https://relay.dev/graphql/connections.htm

  • Method Details

    • getEdges

      @Nullable List<Edge<T>> getEdges()
      Returns:
      a list of Edges that contain a node of data and its cursor. Can be null as defined in the spec.
    • getPageInfo

      PageInfo getPageInfo()
      Returns:
      PageInfo pagination data about that list of edges. Not nullable by definition in the spec.