Package graphql.relay

Interface Edge<T>

All Known Implementing Classes:
DefaultEdge

@PublicApi @NullMarked public interface Edge<T>
Represents an edge in Relay which is essentially a node of data T and the cursor for that node.

See https://facebook.github.io/relay/graphql/connections.htm#sec-Edge-Types

  • Method Details

    • getNode

      @Nullable T getNode()
      Returns:
      the node of data that this edge represents, or null if the node failed to resolve
    • getCursor

      ConnectionCursor getCursor()
      Returns:
      the cursor for this edge node