Class GraphQLList

java.lang.Object
graphql.schema.GraphQLList
All Implemented Interfaces:
GraphQLInputSchemaElement, GraphQLInputType, GraphQLModifiedType, GraphQLNullableType, GraphQLOutputType, GraphQLSchemaElement, GraphQLType

@PublicApi @NullMarked public class GraphQLList extends Object implements GraphQLType, GraphQLInputType, GraphQLOutputType, GraphQLModifiedType, GraphQLNullableType
A modified type that indicates there is a list of the underlying wrapped type, eg a list of strings or a list of booleans.

See https://graphql.org/learn/schema/#lists-and-non-null for more details on the concept