Class FastSchemaGenerator

java.lang.Object
graphql.schema.idl.FastSchemaGenerator

@ExperimentalApi @NullMarked public class FastSchemaGenerator extends Object
A schema generator that uses GraphQLSchema.FastBuilder to construct the schema. GraphQLSchema.FastBuilder has a number of important limitations, so please read its documentation carefully to understand if you should use this instead of the standard SchemaGenerator.
See Also:
  • Constructor Details

    • FastSchemaGenerator

      public FastSchemaGenerator()
  • Method Details

    • makeExecutableSchema

      public GraphQLSchema makeExecutableSchema(TypeDefinitionRegistry typeRegistry, RuntimeWiring wiring)
      Creates an executable schema from a TypeDefinitionRegistry using FastBuilder.
      Parameters:
      typeRegistry - the type definition registry
      wiring - the runtime wiring
      Returns:
      a validated, executable schema
    • makeExecutableSchema

      public GraphQLSchema makeExecutableSchema(SchemaGenerator.Options options, TypeDefinitionRegistry typeRegistry, RuntimeWiring wiring)
      Creates an executable schema from a TypeDefinitionRegistry using FastBuilder.
      Parameters:
      options - the schema generation options
      typeRegistry - the type definition registry
      wiring - the runtime wiring
      Returns:
      an executable schema