Package graphql.schema.impl
package graphql.schema.impl
-
ClassesClassDescriptionA visitor that collects all
GraphQLNamedTypes during schema traversal.A delegating type visitor that allows you to call N visitors in a list and always continues viaTraversalControl.CONTINUEThis class returns a list of strongly connected components (SCC) which are topologically sorted.