public class NoOpPreparsedDocumentProvider extends java.lang.Object implements PreparsedDocumentProvider
| Modifier and Type | Field and Description |
|---|---|
static NoOpPreparsedDocumentProvider |
INSTANCE |
| Constructor and Description |
|---|
NoOpPreparsedDocumentProvider() |
| Modifier and Type | Method and Description |
|---|---|
PreparsedDocumentEntry |
get(java.lang.String query,
java.util.function.Function<java.lang.String,PreparsedDocumentEntry> compute)
This is called to get a "cached" pre-parsed query and if its not present, then the computeFunction
can be called to parse the query
|
public static final NoOpPreparsedDocumentProvider INSTANCE
public PreparsedDocumentEntry get(java.lang.String query, java.util.function.Function<java.lang.String,PreparsedDocumentEntry> compute)
PreparsedDocumentProviderget in interface PreparsedDocumentProviderquery - The graphql querycompute - If the query has not be pre-parsed, this function can be called to parse itPreparsedDocumentEntry